import 'api_user_profile.dart';
import '../basics/api_util.dart';
import 'package:leancloud_storage/leancloud.dart';

// 帐号服务 验证码/登录注册
class APIAccountManager {

  // 获取短信验证码(用于注册，忘记密码)
  static requestSMSCode(String moblie,{Function(String) onSucc, Function(String) onFail}) async {

    final isReachable = await APIUtil.isReachablity();
    if (isReachable == false) {
      if (onFail != null) {
        if (onFail != null) onFail('网络异常,请检查网络');
        return;
      }
    }
    
    if (moblie == null) {
      if (onFail != null) onFail('请输入您的手机号');
      return;
    }
    if (moblie.length != 11) {
      if (onFail != null) onFail('请输入正确的11位手机号');
      return;
    }

    try {
      await LCSMSClient.requestSMSCode(moblie);
      if (onSucc != null) onSucc('验证码获取成功');
    } on LCException catch (e) {
      if (onFail != null) onFail('${e.message}');
    }
  }

  // 验证短信验证码
  static verifyMobilePhone(String moblie, String smsCode,{Function(String) onSucc, Function(String) onFail}) async {

    final isReachable = await APIUtil.isReachablity();
    if (isReachable == false) {
      if (onFail != null) {
        if (onFail != null) onFail('网络异常,请检查网络');
        return;
      }
    }
    // 手机号校验
    if (moblie == null) {
      if (onFail != null) onFail('请输入您的手机号');
      return;
    }
    if (moblie.length != 11) {
      if (onFail != null) onFail('请输入正确的11位手机号');
      return;
    }

    // 短信验证码
    if (smsCode == null) {
      if (onFail != null) onFail('请输入短信验证码');
      return;
    }
    if (smsCode.length != 6) {
      if (onFail != null) onFail('请输入正确的6位短信验证码');
      return;
    }

    try {
      await LCSMSClient.verifyMobilePhone(moblie, smsCode);
      if (onSucc != null) onSucc('验证成功');
    } on LCException catch (e) {
      if (onFail != null) onFail(e.message);
    }
  }

   // 重置密码 - 获取手机验证码
  static requestPasswordResetBySmsCode(String moblie,
      {Function(String) onSucc, Function(String) onFail}) async {
    // 网络检测
    final isReachable = await APIUtil.isReachablity();
    if (isReachable == false) {
      if (onFail != null) {
        if (onFail != null) onFail('网络异常,请检查网络');
        return;
      }
    }
    // 校验
    if (moblie == null) {
      if (onFail != null) onFail('请输入您的手机号');
      return;
    }
    if (moblie.length != 11) {
      if (onFail != null) onFail('请输入正确的11位手机号');
      return;
    }

    try {
      await LCUser.requestPasswordRestBySmsCode(moblie);
      if (onSucc != null) onSucc('验证码获取成功');
    } on LCException catch (e) {
      if (onFail != null) onFail('${e.message}');
    }
  }

  // 重置密码 - 通过短信验证码修改密码
  static resetPasswordBySmsCode(String moblie, String smsCode, String password,
      {Function(String) onSucc, Function(String) onFail}) async {
    // 网络检测
    final isReachable = await APIUtil.isReachablity();
    if (isReachable == false) {
      if (onFail != null) {
        if (onFail != null) onFail('网络异常,请检查网络');
        return;
      }
    }
    // 手机号校验
    if (moblie == null) {
      if (onFail != null) onFail('请输入您的手机号');
      return;
    }
    if (moblie.length != 11) {
      if (onFail != null) onFail('请输入正确的11位手机号');
      return;
    }

    // 短信验证码
    if (smsCode == null) {
      if (onFail != null) onFail('请输入短信验证码');
      return;
    }
    if (smsCode.length != 6) {
      if (onFail != null) onFail('请输入正确的6位短信验证码');
      return;
    }

    // 账户密码
    if (password == null) {
      if (onFail != null) onFail('请输入您的密码');
      return;
    }
    if (password.length == 0) {
      if (onFail != null) onFail('请输入您的密码');
      return;
    }

    try {
      await LCUser.resetPasswordBySmsCode(moblie, smsCode, password);
      if (onSucc != null) onSucc('验证成功');
    } on LCException catch (e) {
      if (onFail != null) onFail(e.message);
    }
  }

  // 通过手机号 + 密码注册 + 建立用户档案
  static signUp(String mobile, String password,{Function(String) onSucc, Function(String) onFail}) async {
    // 网络检测
    final isReachable = await APIUtil.isReachablity();
    if (isReachable == false) {
      if (onFail != null) {
        if (onFail != null) onFail('网络异常,请检查网络');
        return;
      }
    }
    // 手机号校验
    if (mobile == null) {
      if (onFail != null) onFail('请输入您的手机号');
      return;
    }
    if (mobile.length != 11) {
      if (onFail != null) onFail('请输入正确的11位手机号');
      return;
    }
    // 账户密码
    if (password == null) {
      if (onFail != null) onFail('请输入您的密码');
      return;
    }
    if (password.length == 0) {
      if (onFail != null) onFail('请输入您的密码');
      return;
    }

    try {
      LCUser user = LCUser();
      user.username = mobile;
      user.password = password;
      user.mobile = mobile;

      await user.signUp();

      APIUserProfile.createUserProfile(mobile,password,onFail: onFail,onSucc: (_) {
          if (onSucc != null) onSucc('注册成功');
        },
      );
    } on LCException catch (e) {
      final code = e.code;
      var emsg = '注册失败';
      if (code == 214) {
        emsg = '您的手机号已经被注册';
      } else {
        emsg = '注册失败(${e.code})';
      }

      if (onFail != null) onFail(emsg);
    }
  }

  // 普通用户登录
  static login(String moblie, String password,{Function(String) onSucc, Function(String) onFail}) async {

    final isReachable = await APIUtil.isReachablity();
    if (isReachable == false) {
      if (onFail != null) {
        if (onFail != null) onFail('网络异常,请检查网络');
        return;
      }
    }
    // 手机号校验
    if (moblie == null) {
      if (onFail != null) onFail('请输入您的手机号');
      return;
    }
    if (moblie.length != 11) {
      if (onFail != null) onFail('请输入正确的11位手机号');
      return;
    }
    // 账户密码
    if (password == null) {
      if (onFail != null) onFail('请输入您的密码');
      return;
    }
    if (password.length == 0) {
      if (onFail != null) onFail('请输入您的密码');
      return;
    }

    try {
      await LCUser.loginByMobilePhoneNumber(moblie, password);
      if (onSucc != null) onSucc('恭喜,登录成功');
    } on LCException catch (e) {
      final code = e.code;
      var emsg = '对不起,登录失败';
      if (code == 210) {
        emsg = '对不起,登录密码不正确';
      } else if (code == 211) {
        emsg = '对不起,您的手机号尚未完成注册';
      } else if (code == 219) {
        emsg = '登录失败次数超过限制，请稍候15分钟再次尝试，或者通过忘记密码重设密码';
      } else {
        emsg = '对不起,登录失败';
        print(e.code);
      }
      if (onFail != null) onFail(emsg);
    }
  }

  // 管理员用户登录
  static loginAdmin(String moblie, String password,{Function(String) onSucc, Function(String) onFail}) async {

    final isReachable = await APIUtil.isReachablity();
    if (isReachable == false) {
      if (onFail != null) {
        if (onFail != null) onFail('网络异常,请检查网络');
        return;
      }
    }
    // 手机号校验
    if (moblie == null) {
      if (onFail != null) onFail('请输入您的手机号');
      return;
    }
    if (moblie.length != 11) {
      if (onFail != null) onFail('请输入正确的11位手机号');
      return;
    }
    // 账户密码
    if (password == null) {
      if (onFail != null) onFail('请输入您的密码');
      return;
    }
    if (password.length == 0) {
      if (onFail != null) onFail('请输入您的密码');
      return;
    }

    try {
      await LCUser.loginByMobilePhoneNumber(moblie, password);

      APIUserProfile.currentUserProfile(
      onSucc: (data) {
          LCObject userType   = data['userType'] ?? '';
          String userTypeName =  userType['name'] ?? '';
          if(userTypeName == 'admin') {
            if (onSucc != null) onSucc('恭喜,登录成功');
            return;
          }
          else {
             if (onFail != null) onFail('非管理员帐号,请申请开通管理权限');
             return;
          }
        },
        onFail: (msg){
          if (onFail != null) onFail('服务器开小差了,请稍后再试');
          return;
        },
      );

      
    } on LCException catch (e) {
      final code = e.code;
      var emsg = '对不起,登录失败';
      if (code == 210) {
        emsg = '对不起,登录密码不正确';
      } else if (code == 211) {
        emsg = '对不起,您的手机号尚未完成注册';
      } else if (code == 219) {
        emsg = '登录失败次数超过限制，请稍候15分钟再次尝试，或者通过忘记密码重设密码';
      } else {
        emsg = '对不起,登录失败';
        print(e.code);
      }
      if (onFail != null) onFail(emsg);
    }
  }
}