// 产品类接口
import 'package:leancloud_storage/leancloud.dart';
import 'api_scheme.dart';

class APIProduct {

  // 获取所有品类列表
  static getCategoryList({Function(List<LCObject>) onSucc, Function(String) onFail}) async {
    try {
      LCQuery query = LCQuery('ProductCategory');
      query.whereNotEqualTo('isActive', 0);
      query.orderByAscending('createdAt');
      List<LCObject> datas = await query.find();
      if (onSucc != null) onSucc(datas);
    } on LCException catch (_) {
      if (onFail != null) onFail('数据获取失败');
    }
  }

  // 获取用户拥有的产品下的品类列表
  static getCategoryListByUser({Function(List<LCObject>) onSucc, Function(String) onFail}) async {
    APIScheme.getAllSchemeList(
      onFail: onFail,
      onSucc: (schemes) {
        List<LCObject> datas = filterUniqueCategory(schemes);
        if (onSucc != null) onSucc(datas);
      },
    );
  }

  // 分类去重
  static List<LCObject> filterUniqueCategory(List<LCObject> input) {
    List<LCObject> result = [];
    if (input == null) return result;
    if (input.length == 0) return result;

    // 取 scheme并去重
    for (int i = 0; i < input.length; i++) {
      LCObject pItem = input[i];
      LCObject pItemProduct = pItem['product'];
      LCObject pItemCategory = pItemProduct['category'];
      String pItemCategoryId = pItemCategory.objectId;

      final isRepeat = isFoundRepeat(pItemCategoryId, result);

      if (isRepeat == false) {
        result.add(pItem);
      }
    }

    // 取 category 列表
    List<LCObject> categoryList = [];
    for (int p = 0; p < result.length; p++) {
      LCObject item = result[p];
      LCObject product = item['product'];
      LCObject category = product['category'];
      categoryList.add(category);
    }
    return categoryList;
  }

  // 判断重复
  static bool isFoundRepeat(String pickerCategoryId, List<LCObject> tempList) {
    for (int k = 0; k < tempList.length; k++) {
      LCObject kItem = tempList[k];
      LCObject kItemProduct = kItem['product'];
      LCObject kItemCategory = kItemProduct['category'];
      String kItemCategoryId = kItemCategory.objectId;
      if (pickerCategoryId.compareTo(kItemCategoryId) == 0) {
        return true;
      }
    }
    return false;
  } 

  // 获取产品列表
  static getProductList({Function(List<LCObject>) onSucc,Function(String) onFail}) async {

    try {  
      LCQuery query = LCQuery('Product');
      query.whereNotEqualTo('isActive', 0);
      query.include('category');
      query.orderByAscending('createdAt');
      query.limit(300);
      List<LCObject> datas = await query.find();
      if(onSucc != null) onSucc(datas);
    } on LCException catch (_) {
      
      if(onFail != null) onFail('产品列表获取失败');
    }

  }
  
  // 获取新品产品接口
  static getNewProductList({Function(List<LCObject>) onSucc,Function(String) onFail}) async {
    
    try {  
      LCQuery query = LCQuery('Product');
      query.whereNotEqualTo('isActive', 0);
      query.whereNotEqualTo('isNew', 0);
      query.include('category');
      query.orderByAscending('createdAt');
      query.limit(100);
      List<LCObject> datas = await query.find();
      if(onSucc != null) onSucc(datas);
    } on LCException catch (_) {
      if(onFail != null) onFail('服务器开小差了,请稍后再试');
    }

  }

  // 获取左侧产品品类列表(不含新品)
  static getLeftCategoryList({Function(List<LCObject>) onSucc, Function(String) onFail}) async {
    try {
      LCQuery query = LCQuery('ProductCategory');
      query.whereNotEqualTo('isActive', 0);
      query.orderByAscending('createdAt');
      query.limit(100);
      List<LCObject> datas = await query.find();
      if (onSucc != null) onSucc(datas);
    } on LCException catch (_) {
      if (onFail != null) onFail('服务器开小差了,请稍后再试');
    }
  }

  // 根据选中品类获取右侧产品列表
  static getRightProductList(String categoryId,{Function(List<LCObject>) onSucc,Function(String) onFail}) async {
    try {  
      LCQuery catQuery = LCQuery('ProductCategory');
      catQuery.whereEqualTo('objectId', categoryId);
      LCQuery query = LCQuery('Product');
      query.whereMatchesQuery('category', catQuery);
      query.whereNotEqualTo('isActive', 0);
      query.include('category');
      query.orderByAscending('createdAt');
      query.limit(100);
      List<LCObject> datas = await query.find();
      if(onSucc != null) onSucc(datas);
    } on LCException catch (_) {
      if(onFail != null) onFail('服务器开小差了,请稍后再试');
    }

  }

  // 获取新品产品详情
  static getNewProductDetail(String productId,{Function(LCObject product) onSucc,Function(String) onFail}) async {
    try {  
      LCQuery query = LCQuery('Product');
      query.whereEqualTo('objectId', productId);
      query.whereNotEqualTo('isActive', 0);
      query.limit(1);
      LCObject data = await query.first();
      if(onSucc != null) onSucc(data);
    } on LCException catch (_) {
      if(onFail != null) onFail('服务器开小差了,请稍后再试');
    }
  }

  // 获取新品产品详情
  static getNewProductDetailById(int id,{Function(LCObject product) onSucc,Function(String) onFail}) async {
    try {  
      LCQuery query = LCQuery('Product');
      query.whereEqualTo('id', id);
      query.whereNotEqualTo('isActive', 0);
      query.limit(1);
      LCObject data = await query.first();
      if(onSucc != null) onSucc(data);
    } on LCException catch (_) {
      if(onFail != null) onFail('服务器开小差了,请稍后再试');
    }
  }

  // 根据id获取产品SKU
  static getProductSKU(int id,{Function(LCObject sku) onSucc,Function(String) onFail}) async {
    try {  
      LCQuery query = LCQuery('ProductSKU');
      query.whereEqualTo('id', id);
      query.whereNotEqualTo('isActive', 0);
      query.limit(1);
      LCObject data = await query.first();
      if(onSucc != null) onSucc(data);
    } on LCException catch (_) {
      if(onFail != null) onFail('服务器开小差了,请稍后再试');
    }
  }
}