// 方案类接口
import 'package:leancloud_storage/leancloud.dart';
import 'api_user_profile.dart';

class APIScheme {

  // 获取所有方案
  static getAllSchemeList({Function(List<LCObject>) onSucc, Function(String) onFail}) async {
    APIUserProfile.currentUserProfile(
      onFail: onFail,
      onSucc: (userObject) async {
        try {
          LCQuery userQuery = LCQuery('UserProfile');
          userQuery.whereEqualTo('objectId', userObject.objectId);

          LCQuery query = LCQuery('UserScheme');
          query.whereMatchesQuery('user', userQuery);
          query.whereNotEqualTo('isActive', 0);
          query.orderByAscending('createdAt');
          query.include('product');
          query.include('product.category');
          query.include('product.accessType');
          query.limit(300);

          List<LCObject> datas = await query.find();
          if (onSucc != null) onSucc(datas);
        } on LCException catch (_) {
          if (onFail != null) onFail('数据获取失败');
        }
      },
    );
  }

  // 根据品类获取方案
  static getSchemeByCategoryList(String categoryId,{Function(List<LCObject>) onSucc, Function(String) onFail}) async {
    APIUserProfile.currentUserProfile(
      onFail: onFail,
      onSucc: (userObject) async {
        try {
          LCQuery catQuery = LCQuery('ProductCategory');
          catQuery.whereEqualTo('objectId', categoryId);

          LCQuery prdQuery = LCQuery('Product');
          prdQuery.whereMatchesQuery('category', catQuery);

          LCQuery userQuery = LCQuery('UserProfile');
          userQuery.whereEqualTo('objectId', userObject.objectId);

          LCQuery query = LCQuery('UserScheme');

          query.whereNotEqualTo('isActive', 0);
          query.orderByAscending('createdAt');
          query.include('product');
          query.include('product.category');
          query.include('product.accessType');

          query.whereMatchesQuery('product', prdQuery);
          query.whereMatchesQuery('user', userQuery);

          query.limit(300);

          List<LCObject> datas = await query.find();
          if (onSucc != null) onSucc(datas);
        } on LCException catch (_) {
          if (onFail != null) onFail('数据获取失败');
        }
      },
    );
  }
}