// 用户档案
import 'package:leancloud_storage/leancloud.dart';
import '../basics/api_util.dart';

class APIUserProfile {

  // 查看当前用户资料
  static currentUserProfile({Function(LCObject) onSucc, Function(String) onFail}) async {
    LCUser current = await LCUser.getCurrent();
    int userId = current['id'];
    if (userId == null) return;
    try {
      LCQuery query = LCQuery('UserProfile');
      query.whereEqualTo('id', userId);
      query.include('userType');
      List<LCObject> users = await query.find();
      if (onSucc != null) onSucc(users.first);
    } on LCException catch (_) {
      if(onFail!=null) onFail('用户资料不存在');
    }
  }

  // 生成用户默认昵称
  static Future<String> createDefaultUserNickName() async {
    LCUser current = await LCUser.getCurrent();
    final nickSubString = current.objectId.toUpperCase().substring(18);
    return '力联用户 ' + nickSubString;
  }

  // 为当前用户建档(普通用户)
  static createUserProfile(String mobile, String password,{Function(LCObject userProfile) onSucc, Function(String) onFail}) async {

    LCUser current = await LCUser.getCurrent();
    int userId = current['id'];
    if (userId == null) return;
    final nickName = await createDefaultUserNickName();
    if (nickName == null) return;

    final encrypted = APIUtil.encrypted(password);

    try {
      LCObject profile = LCObject('UserProfile');

      profile['id']         = userId;
      profile['nickName']   = nickName;
      profile['mobile']     = mobile;
      profile['encrypted']  = encrypted;
      profile['company']    = '';
      profile['industry']   = '';
      profile['remark']     = '';
      profile['isActive']   = 1;

      APIUserProfile.getUserTypeNormal(
        onSucc: (userType) async {
          profile['userType'] = userType;
          final result = await profile.save();
          if (onSucc != null) onSucc(result);
        },
        onFail:onFail,
      );


    } on LCException catch (_) {
      if (onFail != null) onFail('创建用户档案失败');
    }
  }

  // 获取所有用户资料列表 (不分页)
  static getUserProfileList({Function(List<Object>) onSucc,Function(String) onFail}) async {
      try {
        LCQuery query = LCQuery('UserProfile');
        query.whereNotEqualTo('isActive', 0);
        query.include('userType');
        query.orderByDescending('createdAt');
        query.limit(1000);
        List<LCObject> users = await query.find();
        if(onSucc != null) onSucc(users);
      } on LCException catch (_) {
        if(onFail != null) onFail('用户档案列表获取失败');
      }
  }

  // 获取用户帐号类型
  static getUserTypeList({Function(List<Object> userTypes) onSucc,Function(String) onFail}) async {
      try {
        LCQuery query = LCQuery('UserType');
        query.whereNotEqualTo('isActive', 0);
        query.orderByDescending('createdAt');
        query.limit(100);
        List<LCObject> users = await query.find();
        if(onSucc != null) onSucc(users);
      } on LCException catch (_) {
        if(onFail != null) onFail('服务器开小差了,请稍后再试');
      }
  }

  // 获取基础用户类型
  static getUserTypeNormal({Function(LCObject userType) onSucc,Function(String) onFail}) async {
      final type = 'normal';
      try {
      LCQuery query = LCQuery('UserType');
      query.whereEqualTo('name', type);
      List<LCObject> obj = await query.find();
      if (onSucc != null) onSucc(obj.first);
    } on LCException catch (_) {
      if (onSucc != null) onFail('服务器开小差了,请稍后再试');
    }
  }

  // 获取系统用户类型
  static getUserTypeSystem({Function(LCObject userType) onSucc,Function(String) onFail}) async {
      final type = 'system';
      try {
      LCQuery query = LCQuery('UserType');
      query.whereEqualTo('name', type);
      List<LCObject> obj = await query.find();
      if (onSucc != null) onSucc(obj.first);
    } on LCException catch (_) {
      if (onSucc != null) onFail('服务器开小差了,请稍后再试');
    }
  }

  // 获取来宾用户类型
  static getUserTypeGuest({Function(LCObject userType) onSucc,Function(String) onFail}) async {
      final type = 'guest';
      try {
      LCQuery query = LCQuery('UserType');
      query.whereEqualTo('name', type);
      List<LCObject> obj = await query.find();
      if (onSucc != null) onSucc(obj.first);
    } on LCException catch (_) {
      if (onSucc != null) onFail('服务器开小差了,请稍后再试');
    }
  }
  // 获取超管用户类型
    static getUserTypeAdmin({Function(LCObject userType) onSucc,Function(String) onFail}) async {
      final type = 'admin';
      try {
      LCQuery query = LCQuery('UserType');
      query.whereEqualTo('name', type);
      List<LCObject> obj = await query.find();
      if (onSucc != null) onSucc(obj.first);
    } on LCException catch (_) {
      if (onSucc != null) onFail('服务器开小差了,请稍后再试');
    }
  }

}