import 'dart:math';
import 'package:leancloud_storage/leancloud.dart';
import 'package:connectivity/connectivity.dart';
import 'package:encrypt/encrypt.dart' as EPT;
import 'package:common_utils/common_utils.dart';

class APIUtil {

  // 检测网络状况
  static Future<bool> isReachablity() async {
    var res = await (Connectivity().checkConnectivity());
    return res != ConnectivityResult.none;
  }

  // 加密
  static String encrypted(String password) {
    final key = EPT.Key.fromUtf8(EncryptUtil.encodeMd5('LEAD').toUpperCase());
    final encrypter = EPT.Encrypter(EPT.AES(key,mode:EPT.AESMode.ecb));
    final iv = EPT.IV.fromLength(16);
    final encrypted = encrypter.encrypt(password,iv: iv);
    return encrypted.base64 ?? '';
  }

  // 解密
  static String decrypted(String input) {
   final key = EPT.Key.fromUtf8(EncryptUtil.encodeMd5('LEAD').toUpperCase());
   final encrypter = EPT.Encrypter(EPT.AES(key,mode:EPT.AESMode.ecb));
   final iv = EPT.IV.fromLength(16);
   final plain = encrypter.decrypt(EPT.Encrypted.fromBase64(input),iv: iv);
   return plain;
  }

  // 图片url获取
  static String getImageUrl(LCObject object,String name) {
    String res = '';
    LCFile file = object[name];
    if(file == null) {
      return res;
    }
    final url = file.url ?? '';
    return url;
  }

  // 二维码加壳
  static String shellQRcodeString(String input) {
    return '^(' +  input + ')^';
  }

  // 二维码脱壳
  static String unshellQRcodeString(String input) {
    if(isAvailableQRcode(input) == false) {
      return '';
    }
    final cutHead = input.substring(2);
    final result = cutHead.substring(0,cutHead.length - 2);
    return result;
  }

  // 判断是否是力联二维码
  static bool isAvailableQRcode(String input) {
    if(input == null) return false;
    if(input.length <= 4) return false;
    bool isHaveHead = input.startsWith('^(');
    bool isHaveTail = input.endsWith(')^');
    if(isHaveHead && isHaveTail) return true;
    return false;
  }

  // 二维码加壳(弃用)
  static String shellQRcodeStringHeavy(String input) {
    // DAA3B1E8F6A0603A00B4DE70420B2844 32位
    final shell = EncryptUtil.encodeMd5('LEAD').toUpperCase();
    final head = shell.substring(0,16);
    final tail = shell.substring(16,32);
    return head + input + tail;
  }

  // 二维码脱壳(弃用)
  static String unshellQRcodeStringHeavy(String input) {
    if(isAvailableQRcodeHeavy(input) == false) {
      return '';
    }
    final cutHead = input.substring(16);
    final result = cutHead.substring(0,cutHead.length - 16);
    return result;
  }

  // 判断是否是力联二维码(弃用)
  static bool isAvailableQRcodeHeavy(String input) {
    if(input == null) return false;
    if(input.length <= 32) return false;
    final shell = EncryptUtil.encodeMd5('LEAD').toUpperCase();
    final head = shell.substring(0,16);
    final tail = shell.substring(16,32);
    bool isHaveHead = input.startsWith(head);
    bool isHaveTail = input.endsWith(tail);
    if(isHaveHead && isHaveTail) return true;
    return false;
  }

  // 随机数生成
  static int randomNumber(int min, int max) {
    final _random = Random();
    return min + _random.nextInt(max - min + 1);
  }
}